/**
 * `chunk` divides an array into chunks of the specified size
 */
declare function chunk<T>(array: T[], size: number): T[][];
/**
 * `compact` removes all falsy values from an array
 */
declare function compact<T>(array: T[]): T[];
/**
 * `concat` concatenates multiple arrays
 */
declare function concat<T>(array: T[], ...arrays: T[][]): T[];
/**
 * `difference` creates an array of array values not included in the other given arrays
 */
declare function difference<T>(array: T[], ...arrays: T[][]): T[];
/**
 * `drop` creates a slice of array with n elements dropped from the beginning
 */
declare function drop<T>(array: T[], n?: number): T[];
/**
 * `fill` fills elements of array with value from start up to, but not including, end
 */
declare function fill<T>(array: T[], value: T, start?: number, end?: number): T[];
/**
 * `findIndex` gets the index at which the first occurrence of value is found in array
 */
declare function findIndex<T>(array: T[], predicate: (value: T, index: number, array: T[]) => boolean, fromIndex?: number): number;
/**
 * `findLastIndex` is like `findIndex` but it iterates over elements of collection from right to left.
 */
declare function findLastIndex<T>(array: T[], predicate: (value: T, index: number, array: T[]) => boolean, fromIndex?: number): number;
/**
 * `first` gets the first element of array.
 */
declare function first<T>(array: T[]): T | undefined;
/**
 * `flatten` flattens array a single level deep.
 */
declare function flatten<T>(array: T[][]): T[];
/**
 * `flattenDeep` recursively flattens array.
 */
declare function flattenDeep<T>(array: unknown[]): T[];
/**
 * `flattenDepth` recursively flatten array up to depth times.
 */
declare function flattenDepth(array: unknown[], depth?: number): unknown[];
/**
 * `fromPairs` returns an object composed from key-value pairs.
 */
declare function fromPairs<T extends PropertyKey, U>(pairs: [T, U][]): {
    [K in T]: U;
};
/**
 * `head` gets the first element of array.
 */
declare function head<T>(array: T[]): T | undefined;
/**
 * `indexOf` gets the index at which the first occurrence of value is found in array.
 */
declare function indexOf<T>(array: T[], value: T, fromIndex?: number): number;
/**
 * `initial` gets all but the last element of array.
 */
declare function initial<T>(array: T[]): T[];
/**
 * `intersection` creates an array of unique values that are included in all given arrays.
 */
declare function intersection<T>(...arrays: T[][]): T[];
/**
 * `join` converts all elements in array into a string separated by separator.
 */
declare function join<T>(array: T[], separator?: string): string;
/**
 * `last` gets the last element of array.
 */
declare function last<T>(array: T[]): T | undefined;
/**
 * `lastIndexOf` gets the index at which the last occurrence of value is found in array.
 */
declare function lastIndexOf<T>(array: T[], value: T, fromIndex?: number): number;
/**
 * `nth` gets the element at index n of array. If n is negative, the nth element from the end is returned.
 */
declare function nth<T>(array: T[], n?: number): T | undefined;
/**
 * `pull` removes all given values from array.
 */
declare function pull<T>(array: T[], ...values: T[]): T[];
/**
 * `remove` removes all elements from array that satisfy a condition and returns an array of the removed elements.
 */
declare function remove<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * `reverse` reverses array so that the first element becomes the last, the second element becomes the second to last, and so on.
 */
declare function reverse<T>(array: T[]): T[];
/**
 * `slice` creates a slice of array from start up to, but not including, end.
 */
declare function slice<T>(array: T[], start?: number, end?: number): T[];
/**
 * `tail` gets all but the first element of array.
 */
declare function tail<T>(array: T[]): T[];
/**
 * `take` creates a slice of array with n elements taken from the beginning.
 */
declare function take<T>(array: T[], n?: number): T[];
/**
 * `takeRight` creates a slice of array with n elements taken from the end.
 */
declare function takeRight<T>(array: T[], n?: number): T[];
/**
 * `union` creates an array of unique values, in order, from all given arrays
 */
declare function union<T>(...arrays: T[][]): T[];
/**
 * `uniq` creates a duplicate-free version of an array
 */
declare function uniq<T>(array: T[]): T[];
/**
 * `unzip` is the opposite of `zip`. It receives an array of grouped elements and creates an array regrouping them to their pre-zip configuration.
 */
declare function unzip<T>(array: T[][]): T[][];
/**
 * `without` creates an array excluding all given values.
 */
declare function without<T>(array: T[], ...values: T[]): T[];
/**
 * `xor` creates an array of unique values that is the symmetric difference of the provided arrays.
 */
declare function xor<T>(...arrays: T[][]): T[];
/**
 * `zip` creates an array of grouped elements, the first of which contains the first elements of the given arrays, the second of which contains the second elements of the given arrays, and so on.
 */
declare function zip<T>(...arrays: T[][]): T[][];
/**
 * `zipObject` creates an object composed from arrays of keys and values.
 */
declare function zipObject<T extends PropertyKey, U>(keys: T[], values: U[]): {
    [K in T]: U;
};
/**
 * `differenceBy` is like `difference` except that it accepts iteratee which is invoked for each element of array and values to generate the criterion by which they're compared.
 */
declare function differenceBy<T>(array: T[], values: T[], iteratee: (value: T) => unknown): T[];
/**
 * `pullAll` removes all matching values from array.
 */
declare function pullAll<T>(array: T[], values: T[]): T[];
/**
 * `pullAllBy` is like `pullAll` except that it accepts iteratee which is invoked for each element of array and values to generate the criterion by which uniqueness is computed.
 */
declare function pullAllBy<T>(array: T[], values: T[], iteratee: (value: T) => unknown): T[];
/**
 * `pullAt` removes elements from array corresponding to indexes and returns an array of the removed elements.
 */
declare function pullAt<T>(array: T[], indexes: number[]): T[];
/**
 * `sortedIndex` uses a binary search to determine the lowest index at which value should be inserted into array in order to maintain its sort order.
 */
declare function sortedIndex<T>(array: T[], value: T): number;
/**
 * `unionBy` is like `union` except that it accepts iteratee which is invoked for each element of each arrays to generate the criterion by which uniqueness is computed.
 */
declare function unionBy<T>(iteratee: (value: T) => unknown, ...arrays: T[][]): T[];
/**
 * `uniqBy` is like `uniq` except that it accepts iteratee which is invoked for each element in array to generate the criterion by which uniqueness is computed.
 */
declare function uniqBy<T>(array: T[], iteratee: (value: T) => unknown): T[];
/**
 * `zipObjectDeep` is like `zipObject` except that it supports property paths.
 */
declare function zipObjectDeep<U>(props: string[], values: U[]): unknown;
/**
 * `sortedIndexOf` uses a binary search to determine the lowest index at which value should be inserted into array in order to maintain its sort order. It accepts a third parameter that determines whether to return the leftmost or rightmost match of the value.
 */
declare function sortedIndexOf<T>(array: T[], value: T, isRightmost?: boolean): number;
/**
 * `sortedLastIndex` is similar to `sortedIndex` except that it returns the highest index at which a value should be inserted into array in order to maintain its sort order.
 */
declare function sortedLastIndex<T>(array: T[], value: T): number;
/**
 * `sortedUniq` is similar to `uniq` except that it’s designed and optimized for sorted arrays.
 */
declare function sortedUniq<T>(array: T[]): T[];
/**
 * `takeRightWhile` creates a slice of array with elements taken from the end. Elements are taken until predicate returns falsey.
 */
declare function takeRightWhile<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * `takeWhile` creates a slice of array with elements taken from the beginning. Elements are taken until predicate returns falsey.
 */
declare function takeWhile<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * `xorWith` is like `xor`, except that it accepts comparator which is invoked to compare elements of arrays.
 */
declare function xorWith<T>(arrays: T[][], comparator: (a: T, b: T) => boolean): T[];
/**
 * `zipWith` is like `zip` except that it accepts iteratee to specify how grouped values should be combined.
 */
declare function zipWith<T, U>(arrays: T[][], iteratee: (...values: T[]) => U): U[];
/**
 * `sortedIndexBy` is like `sortedIndex` except that it accepts iteratee which is invoked for each element in array to generate the sort ranking of the value.
 */
declare function sortedIndexBy<T, K>(array: T[], value: T, iteratee: (value: T) => K): number;
/**
 * `differenceWith` creates an array of values not included in the other arrays, using a custom comparator function.
 */
declare function differenceWith<T>(array: T[], comparator: (a: T, b: T) => boolean, ...arrays: T[][]): T[];
/**
 * Creates a slice of `array` with `n` elements dropped from the end.
 */
declare function dropRight<T>(array: T[], n?: number): T[];
/**
 * Creates a slice of `array` excluding elements dropped from the end until the predicate returns falsy.
 */
declare function dropRightWhile<T>(array: T[], predicate: (value: T, index: number, array: T[]) => boolean): T[];
/**
 * Creates a slice of `array` excluding elements dropped from the beginning until the predicate returns falsy.
 */
declare function dropWhile<T>(array: T[], predicate: (value: T, index: number, array: T[]) => boolean): T[];
/**
 * Creates an array of unique values that are included in all given arrays, using a custom iteratee function.
 */
declare function intersectionBy<T>(arrays: T[][], iteratee: (value: T) => unknown): T[];
/**
 * Creates an array of unique values that are included in all given arrays, using a custom comparator function.
 */
declare function intersectionWith<T>(arrays: T[][], comparator: (a: T, b: T) => boolean): T[];
/**
 * Removes all elements from `array` that match the comparator function.
 */
declare function pullAllWith<T>(array: T[], values: T[], comparator: (a: T, b: T) => boolean): T[];
/**
 * Uses binary search to find the index of the last occurrence of a value in a sorted array.
 * If the value is not found, it returns -1.
 */
declare function sortedLastIndexOf<T>(array: T[], value: T): number;
/**
 * Creates a new array of unique values from the provided array,
 * using a custom iteratee function to generate the comparison values.
 * The input array must be sorted.
 */
declare function sortedUniqBy<T, K>(array: T[], iteratee: (value: T) => K): T[];
/**
 * Creates an array of unique values that is the union of all given arrays,
 * using a custom comparator function to determine equality.
 */
declare function unionWith<T>(arrays: T[][], comparator: (a: T, b: T) => boolean): T[];
/**
 * Creates a new array of unique values from the provided array,
 * using a custom comparator function to determine equality.
 */
declare function uniqWith<T>(array: T[], comparator: (a: T, b: T) => boolean): T[];
/**
 * This function is the reverse of `zipWith`.
 * It groups the elements of each array based on the provided iteratee function
 * and returns an array of grouped elements.
 */
declare function unzipWith<T, R>(arrays: T[][], iteratee: (...args: T[]) => R): R[];
/**
 * Creates an array of unique values that is the symmetric difference of the given arrays,
 * using a custom iteratee function to generate the comparison values.
 */
declare function xorBy<T>(arrays: T[][], iteratee: (value: T) => unknown): T[];
/**
 * Creates an object composed of keys generated from the results of running each element of the array through the iteratee function.
 * The order of grouped values is determined by the order they occur in the array.
 */
declare function groupBy<T>(array: T[], iteratee: (value: T) => string): Record<string, T[]>;
/**
 * Checks if a given value is included in the array using strict equality for comparisons.
 */
declare function includes<T>(array: T[], value: T): boolean;
/**
 * Invokes the method at `path` of each element in the array.
 */
declare function invokeMap<T, R>(array: T[], path: (number | string | symbol)[]): Array<R | undefined>;
/**
 * Creates an object composed of keys generated from the results of running each element of the array through the iteratee function.
 */
declare function keyBy<T>(array: T[], iteratee: (value: T) => string): Record<string, T>;
/**
 * Creates an array of values by running each element in the array through the iteratee function.
 */
declare function map<T, R>(array: T[], iteratee: (value: T) => R): R[];
/**
 * Creates an array of elements from the original array, sorted in ascending order by the results of running each element through the iteratees.
 */
declare function orderBy<T>(array: T[], iteratees: ((value: T) => number | string)[], orders?: ("asc" | "desc")[]): T[];
/**
 * Creates an array of elements split into two groups, the first of which contains elements predicate returns truthy for, while the second contains elements predicate returns falsy for.
 */
declare function partition<T>(array: T[], predicate: (value: T) => boolean): [T[], T[]];
/**
 * Reduces the array to a single value by iterating over it from left to right.
 */
declare function reduce<T, R>(array: T[], iteratee: (accumulator: R, value: T) => R, initialValue: R): R;
/**
 * Reduces the array to a single value by iterating over it from right to left.
 */
declare function reduceRight<T, R>(array: T[], iteratee: (accumulator: R, value: T) => R, initialValue: R): R;
/**
 * Creates an array of values from the original array that do not satisfy the predicate.
 */
declare function reject<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * Gets a random element from the array.
 */
declare function sample<T>(array: T[]): T | undefined;
/**
 * Creates an array of random elements from the original array up to the size limit.
 */
declare function sampleSize<T>(array: T[], size: number): T[];
/**
 * Creates a shuffled copy of the array.
 */
declare function shuffle<T>(array: T[]): T[];
/**
 * Returns the number of elements in the array.
 */
declare function size<T>(array: T[]): number;
/**
 * Checks if any element in the array satisfies the predicate.
 */
declare function some<T>(array: T[], predicate: (value: T) => boolean): boolean;
/**
 * Creates a new array of sorted elements by the results of running each element of the original array through the iteratees.
 */
declare function sortBy<T>(array: T[], iteratees: ((value: T) => number | string)[]): T[];
/**
 * Creates an object composed of keys generated from the results of running each element of the array through the iteratee function.
 * The corresponding value of each key is an array of the elements responsible for generating the key.
 */
declare function countBy<T>(array: T[], iteratee: (value: T) => number | string): Record<number | string, number>;
/**
 * Checks if every element in the array satisfies the predicate.
 */
declare function every<T>(array: T[], predicate: (value: T) => boolean): boolean;
/**
 * Creates a new array with all elements that pass the predicate test.
 */
declare function filter<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * Returns the first element in the array that satisfies the predicate.
 */
declare function find<T>(array: T[], predicate: (value: T) => boolean): T | undefined;
/**
 * Returns the last element in the array that satisfies the predicate.
 */
declare function findLast<T>(array: T[], predicate: (value: T) => boolean): T | undefined;
/**
 * Creates a new array by running each element in the array through the iteratee function and flattening the mapped results.
 * The iteratee function should return an array or iterable.
 */
declare function flatMap<T, R>(array: T[], iteratee: (value: T) => R[] | readonly R[]): R[];
/**
 * Recursively flattens the array up to the specified depth.
 */
declare function flatMapDeep<T>(array: T[], depth?: number): T[];
/**
 * Recursively flattens the array until the predicate function returns false.
 */
declare function flatMapDepth<T>(array: T[], predicate: (value: T) => boolean, depth?: number): T[];
/**
 * Executes the provided callback function for each element in the array.
 */
declare function forEach<T>(array: T[], callback: (value: T, index: number, array: T[]) => void): void;
/**
 * Executes the provided callback function for each element in the array in reverse order.
 */
declare function forEachReverse<T>(array: T[], callback: (value: T, index: number, array: T[]) => void): void;
/**
 * Executes the provided callback function for each element in the array from right to left.
 */
declare function forEachRight<T>(array: T[], callback: (value: T, index: number, array: T[]) => void): void;
/**
 * Computes the Cartesian product of multiple sets.
 * The Cartesian product of sets A, B, C, ..., is the set of all ordered pairs (a, b, c, ...),
 * where a is in A, b is in B, c is in C, etc.
 *
 * This function takes an arbitrary number of arrays as input and
 * returns an array of arrays, each of which represents one possible
 * combination of one element from each input array.
 *
 * @param args An arbitrary number of arrays.
 * @returns The Cartesian product of the input arrays.
 */
declare function cartesian<T>(...args: T[][]): T[][];
/**
 * Returns the elements present in the first array but not in the second array.
 * @param firstArray - The first array.
 * @param secondArray - The second array.
 * @returns An array of elements unique to the first array.
 */
declare function getUniqueElementsInFirstArray(firstArray: string[], secondArray: string[]): string[];
/**
 * Returns the elements that are unique to either of the two input arrays.
 * @param firstArray - The first array.
 * @param secondArray - The second array.
 * @returns An array of elements unique to either the first or the second array.
 */
declare function getUniqueElementsInEitherArray(firstArray: string[], secondArray: string[]): string[];
/**
 * Checks if all elements in the first array are also present in the second array.
 * @param firstArray - The first array.
 * @param secondArray - The second array.
 * @returns A boolean indicating whether the first array is a subset of the second.
 */
declare function isFirstArraySubsetOfSecond(firstArray: string[], secondArray: string[]): boolean;
/**
 * Returns all common elements between the two arrays.
 * @param firstArray - The first array.
 * @param secondArray - The second array.
 * @returns An array of elements common to both arrays.
 */
declare function getCommonElements(firstArray: string[], secondArray: string[]): string[];
/**
 * Flattens an array of items. This function can also handle items that have child items.
 * Child items are retrieved using the provided `getChildren` function.
 * The resulting array contains all items and their children in a flat structure.
 * @param inputItems - An array of items to be flattened.
 * @param getChildren - A function that, given an item, returns its children or undefined.
 * @returns A flat array containing all input items and their children.
 */
declare function flattenBy<T>(inputItems: T[], getChildren: ((item: T) => T[] | undefined) | undefined): T[];
/**
 * Plucks the specified property from each object in the array.
 *
 * @template T, K
 * @param {T[]} array - The array of objects.
 * @param {K} key - The property to pluck from each object.
 * @returns {Array<K>} An array of the specified property values.
 */
declare function pluck<T, K extends keyof T>(array: T[], key: K): Array<T[K]>;
/**
 * Retrieves the element at the specified index from an array.
 *
 * @template T - The type of elements in the array.
 * @param {T[]} array - The array from which to retrieve the element.
 * @param {number} index - The index of the element to retrieve. If negative, it is relative to the end of the array.
 * @returns {T | undefined} The element at the specified index, or undefined if the index is out of range.
 */
declare function getElementAt<T>(array: T[], index: number): T | undefined;
declare function inArray<T>(element: T, array: T[]): number;
declare function grep<T>(array: T[], callback: (value: T, index: number, array: T[]) => boolean): T[];
export { cartesian, chunk, compact, concat, countBy, difference, differenceBy, differenceWith, drop, dropRight, dropRightWhile, dropWhile, every, fill, filter, find, findIndex, findLast, findLastIndex, first, flatMap, flatMapDeep, flatMapDepth, flatten, flattenBy, flattenDeep, flattenDepth, forEach, forEachReverse, forEachRight, fromPairs, getCommonElements, getElementAt, getUniqueElementsInEitherArray, getUniqueElementsInFirstArray, grep, groupBy, head, inArray, includes, indexOf, initial, intersection, intersectionBy, intersectionWith, invokeMap, isFirstArraySubsetOfSecond, join, keyBy, last, lastIndexOf, map, nth, orderBy, partition, pluck, pull, pullAll, pullAllBy, pullAllWith, pullAt, reduce, reduceRight, reject, remove, reverse, sample, sampleSize, shuffle, size, slice, some, sortBy, sortedIndex, sortedIndexBy, sortedIndexOf, sortedLastIndex, sortedLastIndexOf, sortedUniq, sortedUniqBy, tail, take, takeRight, takeRightWhile, takeWhile, union, unionBy, unionWith, uniq, uniqBy, uniqWith, unzip, unzipWith, without, xor, xorBy, xorWith, zip, zipObject, zipObjectDeep, zipWith, };
//# sourceMappingURL=array-utilities.d.ts.map