"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.base64ToBlob = void 0;
/**
 * Converts a base64-encoded string to a Blob object.
 * @param {string} base64 - The base64-encoded string representing the data.
 * @returns {Blob} The Blob object created from the base64 data.
 * @example
 * // Example usage:
 * const base64Data = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgA...";
 * const blob = base64ToBlob(base64Data);
 * console.log(blob); // Blob { ... }
 */
function base64ToBlob(base64) {
    var base64Part = base64.substring(base64.indexOf(",") + 1);
    var formatPart = base64.substring(base64.indexOf(":") + 1, base64.indexOf(";"));
    var binary = toArrayBuffer(atob(base64Part));
    var blob = new Blob([binary], { type: formatPart });
    return blob;
    function toArrayBuffer(base64Image) {
        var length = base64Image.length;
        var buf = new ArrayBuffer(length);
        var arr = new Uint8Array(buf);
        for (var i = 0; i < length; i++) {
            arr[i] = base64Image.charCodeAt(i);
        }
        return buf;
    }
}
exports.base64ToBlob = base64ToBlob;
//# sourceMappingURL=blob-utilities.js.map