"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.on = exports.offsetOf = exports.offset = exports.off = exports.not = exports.nextHTMLElement = exports.is = exports.insertBefore = exports.insertAfter = exports.index = exports.htmlOf = exports.html = exports.hide = exports.heightOf = exports.height = exports.hasHTMLElement = exports.hasClass = exports.getSiblings = exports.getParentsRecursively = exports.getNParentsRecursively = exports.getNChildrenRecursively = exports.getChildrenRecursively = exports.findSiblings = exports.findParent = exports.findHTMLElement = exports.findChild = exports.filterHTMLElement = exports.emptyOf = exports.empty = exports.dataOf = exports.data = exports.css = exports.contents = exports.contains = exports.closest = exports.cloneOf = exports.cloneBy = exports.children = exports.beforeHTMLElement = exports.attr = exports.appendTo = exports.append = exports.afterHTMLElement = exports.addHTMLElement = exports.addClassesToAll = exports.addClasses = exports.addClassToAll = exports.addClass = exports.$$ = exports.$ = void 0;
exports.wrapInner = exports.wrapHTMLElement = exports.wrapAll = exports.val = exports.unwrap = exports.trigger = exports.toggleClass = exports.toggle = exports.textOf = exports.text = exports.simplifyHTMLWithRegex = exports.simplifyHTML = exports.siblings = exports.show = exports.scrollTopOf = exports.scrollTop = exports.scrollLeftOf = exports.scrollLeft = exports.replaceWith = exports.replaceElementName = exports.replaceAllElements = exports.replaceAll = exports.removeOf = exports.removeClasses = exports.removeClass = exports.removeChildren = exports.removeBy = exports.removeAttr = exports.prevHTMLElement = exports.prependTo = exports.prepend = exports.positionOf = exports.position = exports.parents = exports.parentOf = exports.parentNode = exports.parent = exports.one = void 0;
function findParent(element, condition) {
    if (!element || !element.parentElement) {
        return null;
    }
    if (condition(element.parentElement)) {
        return element.parentElement;
    }
    return findParent(element.parentElement, condition);
}
exports.findParent = findParent;
function findChild(element, condition) {
    if (!element) {
        return null;
    }
    var children = element.children;
    for (var i = 0; i < children.length; i++) {
        var child = children[i];
        if (condition(child)) {
            return child;
        }
        var result = findChild(child, condition);
        if (result) {
            return result;
        }
    }
    return null;
}
exports.findChild = findChild;
function getParentsRecursively(element) {
    var parents = [];
    while (element && element.parentElement) {
        parents.push(element.parentElement);
        element = element.parentElement;
    }
    return parents;
}
exports.getParentsRecursively = getParentsRecursively;
function getChildrenRecursively(element) {
    var children = [];
    if (!element) {
        return children;
    }
    for (var i = 0; i < element.children.length; i++) {
        var child = element.children[i];
        children.push(child);
        children.push.apply(children, __spreadArray([], __read(getChildrenRecursively(child)), false));
    }
    return children;
}
exports.getChildrenRecursively = getChildrenRecursively;
function getNParentsRecursively(element, n) {
    var parents = [];
    while (element && element.parentElement && parents.length < n) {
        parents.push(element.parentElement);
        element = element.parentElement;
    }
    return parents;
}
exports.getNParentsRecursively = getNParentsRecursively;
function getNChildrenRecursively(element, n) {
    var children = [];
    if (!element) {
        return children;
    }
    for (var i = 0; i < element.children.length && children.length < n; i++) {
        var child = element.children[i];
        children.push(child);
        children.push.apply(children, __spreadArray([], __read(getNChildrenRecursively(child, n - children.length)), false));
    }
    return children;
}
exports.getNChildrenRecursively = getNChildrenRecursively;
function getSiblings(element, siblingType) {
    if (siblingType === void 0) { siblingType = "both"; }
    var parent = element.parentElement;
    if (!parent) {
        return [];
    }
    var allSiblings = Array.from(parent.children);
    var elementIndex = allSiblings.indexOf(element);
    var siblings;
    switch (siblingType) {
        case "prev":
            siblings = allSiblings.slice(0, elementIndex);
            break;
        case "next":
            siblings = allSiblings.slice(elementIndex + 1);
            break;
        case "both":
        default:
            siblings = allSiblings.filter(function (sibling) { return sibling !== element; });
            break;
    }
    return siblings;
}
exports.getSiblings = getSiblings;
function findSiblings(element, condition, siblingType) {
    if (siblingType === void 0) { siblingType = "both"; }
    var siblings = getSiblings(element, siblingType);
    return siblings.filter(condition);
}
exports.findSiblings = findSiblings;
function simplifyHTML(htmlString) {
    var parser = new DOMParser();
    var doc = parser.parseFromString(htmlString, "text/html");
    var elements = doc.querySelectorAll("*");
    elements.forEach(function (element) {
        var attributes = Array.from(element.attributes);
        attributes.forEach(function (attr) { return element.removeAttribute(attr.name); });
    });
    return doc.body.innerHTML;
}
exports.simplifyHTML = simplifyHTML;
function simplifyHTMLWithRegex(htmlString) {
    var strippedAttributes = htmlString.replace(/<([\w]+)\s*[^>]*>/g, "<$1>");
    var strippedSelfClosing = strippedAttributes.replace(/<([\w]+)\s*\/>/g, "<$1>");
    return strippedSelfClosing;
}
exports.simplifyHTMLWithRegex = simplifyHTMLWithRegex;
function replaceAllElements(htmlString, newElement) {
    var replacedOpeningTags = htmlString.replace(/<(\w+)(\s*[^>]*)>/g, "<".concat(newElement, "$2>"));
    var replacedTags = replacedOpeningTags.replace(/<\/\w+>/g, "</".concat(newElement, ">"));
    return replacedTags;
}
exports.replaceAllElements = replaceAllElements;
function replaceElementName(htmlString, oldElement, newElement) {
    var replacedOpeningTags = htmlString.replace(new RegExp("<".concat(oldElement, "(\\s*\n[^>]*)>"), "gi"), "<".concat(newElement, "$1>"));
    var replacedTags = replacedOpeningTags.replace(new RegExp("</".concat(oldElement, ">"), "gi"), "</".concat(newElement, ">"));
    return replacedTags;
}
exports.replaceElementName = replaceElementName;
function removeChildren(parentElement) {
    while (parentElement.firstChild) {
        parentElement.removeChild(parentElement.firstChild);
    }
}
exports.removeChildren = removeChildren;
function addClassToAll(selector, className) {
    var elements = document.querySelectorAll(selector);
    elements.forEach(function (element) { return element.classList.add(className); });
}
exports.addClassToAll = addClassToAll;
function addClassesToAll(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var elements = document.querySelectorAll(selector);
    var _loop_1 = function (index_1) {
        var cls = classNames[index_1];
        elements.forEach(function (element) { return element.classList.add(cls); });
    };
    for (var index_1 = 0; index_1 < classNames.length; index_1++) {
        _loop_1(index_1);
    }
}
exports.addClassesToAll = addClassesToAll;
function css(selector, propertyName, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.style.setProperty(propertyName, value);
    return el;
}
exports.css = css;
function attr(selector, attribute, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.setAttribute(attribute, value);
    return el;
}
exports.attr = attr;
function removeAttr(selector, attribute) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.removeAttribute(attribute);
    return el;
}
exports.removeAttr = removeAttr;
function hasClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return false;
    }
    return el.classList.contains(className);
}
exports.hasClass = hasClass;
function addClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.add(className);
    return el;
}
exports.addClass = addClass;
function addClasses(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    for (var index_2 = 0; index_2 < classNames.length; index_2++) {
        var cls = classNames[index_2];
        el.classList.add(cls);
    }
    return el;
}
exports.addClasses = addClasses;
function removeClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.remove(className);
    return el;
}
exports.removeClass = removeClass;
function removeClasses(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    for (var index_3 = 0; index_3 < classNames.length; index_3++) {
        var cls = classNames[index_3];
        el.classList.remove(cls);
    }
    return el;
}
exports.removeClasses = removeClasses;
function toggleClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.toggle(className);
    return el;
}
exports.toggleClass = toggleClass;
function offsetOf(el) {
    var rect = el.getBoundingClientRect();
    return {
        left: rect.left + window.scrollX,
        top: rect.top + window.scrollY,
    };
}
exports.offsetOf = offsetOf;
function offset(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    var rect = el.getBoundingClientRect();
    return {
        left: rect.left + window.scrollX,
        top: rect.top + window.scrollY,
    };
}
exports.offset = offset;
function parent(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.parentElement;
}
exports.parent = parent;
function parentNode(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.parentNode;
}
exports.parentNode = parentNode;
function dataOf(element, key, value) {
    if (typeof value !== "undefined") {
        element.dataset[key] = String(value);
    }
    else {
        return element.dataset[key];
    }
}
exports.dataOf = dataOf;
function data(selector, key, value) {
    var element = document.querySelector(selector);
    if (!element) {
        return null;
    }
    if (typeof value !== "undefined") {
        element.dataset[key] = String(value);
    }
    else {
        return element.dataset[key];
    }
}
exports.data = data;
function positionOf(el) {
    return { left: el.offsetLeft, top: el.offsetTop };
}
exports.positionOf = positionOf;
function position(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return { left: el.offsetLeft, top: el.offsetTop };
}
exports.position = position;
function scrollTopOf(el, value) {
    if (value !== undefined) {
        el.scrollTop = value;
        return el;
    }
    else {
        return el.scrollTop;
    }
}
exports.scrollTopOf = scrollTopOf;
function scrollLeftOf(el, value) {
    if (value !== undefined) {
        el.scrollLeft = value;
        return el;
    }
    else {
        return el.scrollLeft;
    }
}
exports.scrollLeftOf = scrollLeftOf;
function scrollTop(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.scrollTop = value;
        return el;
    }
    else {
        return el.scrollTop;
    }
}
exports.scrollTop = scrollTop;
function scrollLeft(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.scrollLeft = value;
        return el;
    }
    else {
        return el.scrollLeft;
    }
}
exports.scrollLeft = scrollLeft;
function heightOf(el, value) {
    if (value !== undefined) {
        el.style.height = value;
        return el;
    }
    else {
        return el.offsetHeight;
    }
}
exports.heightOf = heightOf;
function height(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.style.height = value;
        return el;
    }
    else {
        return el.offsetHeight;
    }
}
exports.height = height;
function removeOf(el) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.removeChild(el);
}
exports.removeOf = removeOf;
function removeBy(selector) {
    var _a;
    var el = document.querySelector(selector);
    if (el)
        (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.removeChild(el);
}
exports.removeBy = removeBy;
function emptyOf(el) {
    el.innerHTML = "";
    return el;
}
exports.emptyOf = emptyOf;
function empty(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.innerHTML = "";
    return el;
}
exports.empty = empty;
function cloneOf(el) {
    return el.cloneNode(true);
}
exports.cloneOf = cloneOf;
function cloneBy(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.cloneNode(true);
}
exports.cloneBy = cloneBy;
function htmlOf(el, value) {
    if (value !== undefined) {
        el.innerHTML = value;
        return el;
    }
    else {
        return el.innerHTML;
    }
}
exports.htmlOf = htmlOf;
function textOf(el, value) {
    if (value !== undefined) {
        el.textContent = value;
        return el;
    }
    else {
        return el.textContent;
    }
}
exports.textOf = textOf;
function html(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.innerHTML = value;
        return el;
    }
    else {
        return el.innerHTML;
    }
}
exports.html = html;
function text(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.textContent = value;
        return el;
    }
    else {
        return el.textContent;
    }
}
exports.text = text;
function append(el, child) {
    el.appendChild(child);
    return el;
}
exports.append = append;
function prepend(el, child) {
    el.insertBefore(child, el.firstChild);
    return el;
}
exports.prepend = prepend;
function afterHTMLElement(el, sibling) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(sibling, el.nextSibling);
}
exports.afterHTMLElement = afterHTMLElement;
function beforeHTMLElement(el, sibling) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(sibling, el);
}
exports.beforeHTMLElement = beforeHTMLElement;
function replaceWith(el, newEl) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.replaceChild(newEl, el);
}
exports.replaceWith = replaceWith;
function appendTo(el, parent) {
    parent.appendChild(el);
    return el;
}
exports.appendTo = appendTo;
function prependTo(el, parent) {
    parent.insertBefore(el, parent.firstChild);
    return el;
}
exports.prependTo = prependTo;
function insertAfter(el, refEl) {
    var _a;
    (_a = refEl.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(el, refEl.nextSibling);
}
exports.insertAfter = insertAfter;
function insertBefore(el, refEl) {
    var _a;
    (_a = refEl.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(el, refEl);
}
exports.insertBefore = insertBefore;
function replaceAll(el, selector) {
    document.querySelectorAll(selector).forEach(function (targetEl) {
        var _a;
        var cloneEl = el.cloneNode(true);
        (_a = targetEl.parentNode) === null || _a === void 0 ? void 0 : _a.replaceChild(cloneEl, targetEl);
    });
}
exports.replaceAll = replaceAll;
function findHTMLElement(el, selector) {
    return el.querySelectorAll(selector);
}
exports.findHTMLElement = findHTMLElement;
function filterHTMLElement(els, filterFn) {
    return els.filter(filterFn);
}
exports.filterHTMLElement = filterHTMLElement;
function hasHTMLElement(el, selector) {
    return el.querySelector(selector) !== null;
}
exports.hasHTMLElement = hasHTMLElement;
function not(els, filterFn) {
    return els.filter(function (e) { return !filterFn(e); });
}
exports.not = not;
function is(el, selector) {
    return el.matches(selector);
}
exports.is = is;
function addHTMLElement(el) {
    var elements = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        elements[_i - 1] = arguments[_i];
    }
    return __spreadArray([el], __read(elements), false);
}
exports.addHTMLElement = addHTMLElement;
function contents(el) {
    return Array.from(el.childNodes);
}
exports.contents = contents;
function closest(el, selector) {
    return el.closest(selector);
}
exports.closest = closest;
function parents(el, selector) {
    var parents = [];
    for (var parent_1 = el.parentElement; parent_1; parent_1 = parent_1.parentElement) {
        if (!selector || parent_1.matches(selector)) {
            parents.push(parent_1);
        }
    }
    return parents;
}
exports.parents = parents;
function parentOf(el) {
    return el.parentElement;
}
exports.parentOf = parentOf;
function children(el, selector) {
    return Array.from(el.children).filter(function (child) { return !selector || child.matches(selector); });
}
exports.children = children;
function siblings(el, selector) {
    var _a;
    return Array.from(((_a = el.parentElement) === null || _a === void 0 ? void 0 : _a.children) || []).filter(function (sibling) { return sibling !== el && (!selector || sibling.matches(selector)); });
}
exports.siblings = siblings;
function prevHTMLElement(el) {
    return el.previousElementSibling;
}
exports.prevHTMLElement = prevHTMLElement;
function nextHTMLElement(el) {
    return el.nextElementSibling;
}
exports.nextHTMLElement = nextHTMLElement;
function index(el) {
    var _a;
    return Array.from(((_a = el.parentElement) === null || _a === void 0 ? void 0 : _a.children) || []).indexOf(el);
}
exports.index = index;
function wrapHTMLElement(el, wrapper) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(wrapper, el);
    wrapper.appendChild(el);
}
exports.wrapHTMLElement = wrapHTMLElement;
function wrapAll(els, wrapper) {
    var _a;
    if (els.length === 0)
        return;
    (_a = els[0].parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(wrapper, els[0]);
    els.forEach(function (el) { return wrapper.appendChild(el); });
}
exports.wrapAll = wrapAll;
function wrapInner(el, wrapper) {
    Array.from(el.childNodes).forEach(function (child) { return wrapper.appendChild(child); });
    el.appendChild(wrapper);
}
exports.wrapInner = wrapInner;
function unwrap(el) {
    var parent = el.parentNode;
    if (!parent)
        return;
    while (el.firstChild)
        parent.insertBefore(el.firstChild, el);
    parent.removeChild(el);
}
exports.unwrap = unwrap;
function val(el, value) {
    if (value !== undefined) {
        el.value = value;
        return el;
    }
    else {
        return el.value;
    }
}
exports.val = val;
function on(el, event, handler) {
    el.addEventListener(event, handler);
    return el;
}
exports.on = on;
function off(el, event, handler) {
    el.removeEventListener(event, handler);
    return el;
}
exports.off = off;
function contains(container, contained) {
    return container.contains(contained);
}
exports.contains = contains;
function one(el, event, handler) {
    var listener = function (ev) {
        el.removeEventListener(event, listener);
        handler(ev);
    };
    el.addEventListener(event, listener);
    return el;
}
exports.one = one;
function trigger(el, event) {
    var evt = new CustomEvent(event, {
        bubbles: true,
        cancelable: false,
    });
    el.dispatchEvent(evt);
    return el;
}
exports.trigger = trigger;
function show(el) {
    el.style.display = "";
    return el;
}
exports.show = show;
function hide(el) {
    el.style.display = "none";
    return el;
}
exports.hide = hide;
function toggle(el) {
    el.style.display = el.style.display === "none" ? "" : "none";
    return el;
}
exports.toggle = toggle;
function $(selector) {
    return document.querySelector(selector);
}
exports.$ = $;
function $$(selector) {
    return document.querySelectorAll(selector);
}
exports.$$ = $$;
//# sourceMappingURL=dom-utilities.js.map