"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unflattenJson = exports.tryValidateJson = exports.isValidJson = exports.getObjectKeyValuePairs = exports.getJsonPropertyInfos = exports.getJsonPropertiesWithType = exports.getJsonProperties = exports.flattenJson = void 0;
function getJsonPropertyInfos(obj) {
    var result = [];
    var walked = [];
    var stack = [{ obj: obj, stack: "" }];
    while (stack.length > 0) {
        var _a = stack.pop(), itemObj = _a.obj, itemStack = _a.stack;
        if (typeof itemObj === "object" && itemObj !== null) {
            for (var property in itemObj) {
                if (Object.prototype.hasOwnProperty.call(itemObj, property)) {
                    var value = itemObj[property];
                    var valueType = typeof value;
                    if (valueType === "object" && value != null) {
                        if (!walked.includes(value)) {
                            walked.push(value);
                            var newStack = itemStack
                                ? "".concat(itemStack, ".").concat(property)
                                : property;
                            stack.push({ obj: value, stack: newStack });
                        }
                    }
                    result.push({
                        name: itemStack ? "".concat(itemStack, ".").concat(property) : property,
                        type: valueType,
                        value: value,
                    });
                }
            }
        }
    }
    return result;
}
exports.getJsonPropertyInfos = getJsonPropertyInfos;
function getJsonProperties(obj, hasIndexer) {
    if (hasIndexer === void 0) { hasIndexer = true; }
    return getJsonPropertyInfos(obj)
        .map(function (prop) {
        return hasIndexer ? prop.name.replace(/\.[0-9]+/g, "") : prop.name;
    })
        .filter(function (prop, index, self) { return self.indexOf(prop) === index; });
}
exports.getJsonProperties = getJsonProperties;
function getJsonPropertiesWithType(obj, hasIndexer) {
    if (hasIndexer === void 0) { hasIndexer = true; }
    return getJsonPropertyInfos(obj)
        .map(function (prop) {
        return hasIndexer
            ? "".concat(prop.name.replace(/\.[0-9]+/g, ""), "-").concat(prop.type)
            : "".concat(prop.name, "-").concat(prop.type);
    })
        .filter(function (prop, index, self) { return self.indexOf(prop) === index; });
}
exports.getJsonPropertiesWithType = getJsonPropertiesWithType;
function isValidJson(str) {
    try {
        JSON.parse(str);
        return true;
    }
    catch (e) {
        return false;
    }
}
exports.isValidJson = isValidJson;
function tryValidateJson(str) {
    try {
        var val = JSON.parse(str);
        return {
            isValid: true,
            value: val,
        };
    }
    catch (e) {
        return {
            isValid: false,
            value: undefined,
        };
    }
}
exports.tryValidateJson = tryValidateJson;
function getObjectKeyValuePairs(obj, separator) {
    if (separator === void 0) { separator = "."; }
    return extract(obj);
    function extract(obj, parentKey) {
        return Object.entries(obj).flatMap(function (_a) {
            var _b = __read(_a, 2), key = _b[0], value = _b[1];
            var newKey = parentKey ? "".concat(parentKey).concat(separator).concat(key) : key;
            if (typeof value === "object" && value !== null) {
                return extract(value, newKey);
            }
            else {
                return [[newKey, value]];
            }
        });
    }
}
exports.getObjectKeyValuePairs = getObjectKeyValuePairs;
function flattenJson(obj, separator, prefix) {
    if (prefix === void 0) { prefix = ""; }
    return flattenRecursively(obj, separator, prefix, {});
    function flattenRecursively(obj, separator, prefix, result) {
        if (result === void 0) { result = {}; }
        Object.entries(obj).forEach(function (_a) {
            var _b = __read(_a, 2), key = _b[0], value = _b[1];
            var newKey = prefix ? "".concat(prefix).concat(separator).concat(key) : key;
            if (typeof value === "object" &&
                value !== null &&
                !Array.isArray(value)) {
                flattenRecursively(value, separator, newKey, result);
            }
            else {
                result[newKey] = value;
            }
        });
        return result;
    }
}
exports.flattenJson = flattenJson;
function unflattenJson(obj, separator) {
    var result = {};
    Object.entries(obj).forEach(function (_a) {
        var _b = __read(_a, 2), key = _b[0], value = _b[1];
        key.split(separator).reduce(function (current, part, index, keys) {
            if (index === keys.length - 1) {
                current[part] = value;
            }
            else {
                current[part] = current[part] || {};
            }
            return current[part];
        }, result);
    });
    return result;
}
exports.unflattenJson = unflattenJson;
//# sourceMappingURL=json-utilities.js.map