/**
 * Clamps `number` within the inclusive `lower` and `upper` bounds.
 */
declare function clamp(number: number, lower?: number, upper?: number): number;
/**
 * Checks if `number` is within the range specified by `start` and up to, but not including, `end`.
 * If `end` is not specified, it's set to `start` with `start` then set to 0.
 */
declare function inRange(number: number, start: number, end?: number): boolean;
/**
 * Generates a random number between the inclusive `lower` and `upper` bounds.
 * If only `upper` is provided, the range is set from 0 to `upper`.
 * If no arguments are provided, the range is set from 0 to 1.
 */
declare function random(lower?: number, upper?: number): number;
/**
 * Computes the ceiling of `number`.
 */
declare function ceil(number: number, precision?: number): number;
/**
 * Divides `dividend` by `divisor`.
 */
declare function divide(dividend: number, divisor: number): number;
/**
 * Computes the floor of `number`.
 */
declare function floor(number: number, precision?: number): number;
/**
 * Computes the maximum value of `array`.
 */
declare function max(array: number[]): number;
/**
 * Computes the maximum value of `array` based on the result of `iteratee` for each element.
 */
declare function maxBy<T>(array: T[], iteratee: (value: T) => number): T | undefined;
/**
 * Computes the mean of the values in `array`.
 */
declare function mean(array: number[]): number;
/**
 * Computes the mean of the values in `array` based on the result of `iteratee` for each element.
 */
declare function meanBy<T>(array: T[], iteratee: (value: T) => number): number;
/**
 * Computes the minimum value of `array`.
 */
declare function min(array: number[]): number;
/**
 * Computes the minimum value of `array` based on the result of `iteratee` for each element.
 */
declare function minBy<T>(array: T[], iteratee: (value: T) => number): T | undefined;
/**
 * Multiplies two numbers.
 */
declare function multiply(a: number, b: number): number;
/**
 * Rounds `number` to the nearest integer.
 */
declare function round(number: number): number;
/**
 * Subtracts `subtrahend` from `minuend`.
 */
declare function subtract(minuend: number, subtrahend: number): number;
/**
 * Computes the sum of the values in `array`.
 */
declare function sum(array: number[]): number;
/**
 * Computes the sum of the values in `array` based on the result of `iteratee` for each element.
 */
declare function sumBy<T>(array: T[], iteratee: (value: T) => number): number;
/**
 * Adds two or more numbers together.
 */
declare function add(...numbers: number[]): number;
export { add, ceil, clamp, divide, floor, inRange, max, maxBy, mean, meanBy, min, minBy, multiply, random, round, subtract, sum, sumBy, };
//# sourceMappingURL=number-utilities.d.ts.map