"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sumBy = exports.sum = exports.subtract = exports.round = exports.random = exports.multiply = exports.minBy = exports.min = exports.meanBy = exports.mean = exports.maxBy = exports.max = exports.inRange = exports.floor = exports.divide = exports.clamp = exports.ceil = exports.add = void 0;
/**
 * Clamps `number` within the inclusive `lower` and `upper` bounds.
 */
function clamp(number, lower, upper) {
    if (lower !== undefined && number < lower) {
        return lower;
    }
    else if (upper !== undefined && number > upper) {
        return upper;
    }
    else {
        return number;
    }
}
exports.clamp = clamp;
/**
 * Checks if `number` is within the range specified by `start` and up to, but not including, `end`.
 * If `end` is not specified, it's set to `start` with `start` then set to 0.
 */
function inRange(number, start, end) {
    var _a;
    if (end === undefined) {
        end = start;
        start = 0;
    }
    if (start > end) {
        _a = __read([end, start], 2), start = _a[0], end = _a[1];
    }
    return number >= start && number < end;
}
exports.inRange = inRange;
/**
 * Generates a random number between the inclusive `lower` and `upper` bounds.
 * If only `upper` is provided, the range is set from 0 to `upper`.
 * If no arguments are provided, the range is set from 0 to 1.
 */
function random(lower, upper) {
    if (lower === undefined && upper === undefined) {
        return Math.random();
    }
    else if (lower !== undefined && upper === undefined) {
        return lower + Math.random() * (1 - lower);
    }
    else if (lower !== undefined && upper !== undefined) {
        return lower + Math.random() * (upper - lower);
    }
    else {
        return Math.random();
    }
}
exports.random = random;
/**
 * Computes the ceiling of `number`.
 */
function ceil(number, precision) {
    if (precision === void 0) { precision = 0; }
    var multiplier = Math.pow(10, precision);
    return Math.ceil(number * multiplier) / multiplier;
}
exports.ceil = ceil;
/**
 * Divides `dividend` by `divisor`.
 */
function divide(dividend, divisor) {
    return dividend / divisor;
}
exports.divide = divide;
/**
 * Computes the floor of `number`.
 */
function floor(number, precision) {
    if (precision === void 0) { precision = 0; }
    var multiplier = Math.pow(10, precision);
    return Math.floor(number * multiplier) / multiplier;
}
exports.floor = floor;
/**
 * Computes the maximum value of `array`.
 */
function max(array) {
    return Math.max.apply(Math, __spreadArray([], __read(array), false));
}
exports.max = max;
/**
 * Computes the maximum value of `array` based on the result of `iteratee` for each element.
 */
function maxBy(array, iteratee) {
    if (array.length === 0) {
        return undefined;
    }
    var maxVal = iteratee(array[0]);
    var maxValue = array[0];
    for (var i = 1; i < array.length; i++) {
        var val = iteratee(array[i]);
        if (val > maxVal) {
            maxVal = val;
            maxValue = array[i];
        }
    }
    return maxValue;
}
exports.maxBy = maxBy;
/**
 * Computes the mean of the values in `array`.
 */
function mean(array) {
    if (array.length === 0) {
        return NaN;
    }
    return sum(array) / array.length;
}
exports.mean = mean;
/**
 * Computes the mean of the values in `array` based on the result of `iteratee` for each element.
 */
function meanBy(array, iteratee) {
    if (array.length === 0) {
        return NaN;
    }
    return sumBy(array, iteratee) / array.length;
}
exports.meanBy = meanBy;
/**
 * Computes the minimum value of `array`.
 */
function min(array) {
    return Math.min.apply(Math, __spreadArray([], __read(array), false));
}
exports.min = min;
/**
 * Computes the minimum value of `array` based on the result of `iteratee` for each element.
 */
function minBy(array, iteratee) {
    if (array.length === 0) {
        return undefined;
    }
    var minVal = iteratee(array[0]);
    var minValue = array[0];
    for (var i = 1; i < array.length; i++) {
        var val = iteratee(array[i]);
        if (val < minVal) {
            minVal = val;
            minValue = array[i];
        }
    }
    return minValue;
}
exports.minBy = minBy;
/**
 * Multiplies two numbers.
 */
function multiply(a, b) {
    return a * b;
}
exports.multiply = multiply;
/**
 * Rounds `number` to the nearest integer.
 */
function round(number) {
    return Math.round(number);
}
exports.round = round;
/**
 * Subtracts `subtrahend` from `minuend`.
 */
function subtract(minuend, subtrahend) {
    return minuend - subtrahend;
}
exports.subtract = subtract;
/**
 * Computes the sum of the values in `array`.
 */
function sum(array) {
    return array.reduce(function (total, value) { return total + value; }, 0);
}
exports.sum = sum;
/**
 * Computes the sum of the values in `array` based on the result of `iteratee` for each element.
 */
function sumBy(array, iteratee) {
    return array.reduce(function (total, value) { return total + iteratee(value); }, 0);
}
exports.sumBy = sumBy;
/**
 * Adds two or more numbers together.
 */
function add() {
    var numbers = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        numbers[_i] = arguments[_i];
    }
    return numbers.reduce(function (sum, num) { return sum + num; }, 0);
}
exports.add = add;
//# sourceMappingURL=number-utilities.js.map