declare function sleepAsync(milliseconds?: number): Promise<unknown>;
declare function sleep(milliseconds?: number): void;
declare function promiseWrap<T>(promise: Promise<T>, onfinally?: () => void): Promise<unknown[]>;
declare function toPromise<T>(value: T): Promise<T>;
declare const promisify: (fn: (...args: unknown[]) => void) => (...args: unknown[]) => Promise<unknown>;
export interface PollingOption {
    attempts?: number;
    errorMessage?: string;
    ignoreFailureException?: boolean;
    interval?: number | number[];
    logCallback?: (status: PollingStatus) => void;
    mode: "retry" | "timeout";
    postFailureCallback?: () => boolean | void;
    timeout?: number;
}
export interface PollingStatus {
    attempt: number;
    dateTimeNow: string;
    executionTime: number;
    interval: number;
    maxAttempts: number;
    status: boolean;
}
declare function polling(check: () => boolean, option: PollingOption): Promise<boolean>;
export interface Abortable {
    abort: (reason?: string) => void;
    readonly abortReason?: string;
}
export interface ExecutorFunction<T> {
    (resolve: (value: PromiseLike<T> | T) => void, reject: (reason?: unknown) => void): void;
}
export interface AbortableExecutorFunction<T> {
    (resolve: (value: PromiseLike<T> | T) => void, reject: (reason?: unknown) => void, abortSignal: AbortSignal): void;
}
declare class AbortablePromise<T> extends Promise<T> implements Abortable {
    static from: <T_1>(promise: Promise<T_1>) => AbortablePromise<T_1>;
    private _abortReason?;
    abort: Abortable["abort"];
    constructor(executor: AbortableExecutorFunction<T>);
    get abortReason(): string | undefined;
}
declare class AbortError extends Error {
    constructor(message?: string);
}
export { AbortError, AbortablePromise, polling, promiseWrap, promisify, sleep, sleepAsync, toPromise, };
//# sourceMappingURL=promise-utilities.d.ts.map