var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
function findParent(element, condition) {
    if (!element || !element.parentElement) {
        return null;
    }
    if (condition(element.parentElement)) {
        return element.parentElement;
    }
    return findParent(element.parentElement, condition);
}
function findChild(element, condition) {
    if (!element) {
        return null;
    }
    var children = element.children;
    for (var i = 0; i < children.length; i++) {
        var child = children[i];
        if (condition(child)) {
            return child;
        }
        var result = findChild(child, condition);
        if (result) {
            return result;
        }
    }
    return null;
}
function getParentsRecursively(element) {
    var parents = [];
    while (element && element.parentElement) {
        parents.push(element.parentElement);
        element = element.parentElement;
    }
    return parents;
}
function getChildrenRecursively(element) {
    var children = [];
    if (!element) {
        return children;
    }
    for (var i = 0; i < element.children.length; i++) {
        var child = element.children[i];
        children.push(child);
        children.push.apply(children, __spreadArray([], __read(getChildrenRecursively(child)), false));
    }
    return children;
}
function getNParentsRecursively(element, n) {
    var parents = [];
    while (element && element.parentElement && parents.length < n) {
        parents.push(element.parentElement);
        element = element.parentElement;
    }
    return parents;
}
function getNChildrenRecursively(element, n) {
    var children = [];
    if (!element) {
        return children;
    }
    for (var i = 0; i < element.children.length && children.length < n; i++) {
        var child = element.children[i];
        children.push(child);
        children.push.apply(children, __spreadArray([], __read(getNChildrenRecursively(child, n - children.length)), false));
    }
    return children;
}
function getSiblings(element, siblingType) {
    if (siblingType === void 0) { siblingType = "both"; }
    var parent = element.parentElement;
    if (!parent) {
        return [];
    }
    var allSiblings = Array.from(parent.children);
    var elementIndex = allSiblings.indexOf(element);
    var siblings;
    switch (siblingType) {
        case "prev":
            siblings = allSiblings.slice(0, elementIndex);
            break;
        case "next":
            siblings = allSiblings.slice(elementIndex + 1);
            break;
        case "both":
        default:
            siblings = allSiblings.filter(function (sibling) { return sibling !== element; });
            break;
    }
    return siblings;
}
function findSiblings(element, condition, siblingType) {
    if (siblingType === void 0) { siblingType = "both"; }
    var siblings = getSiblings(element, siblingType);
    return siblings.filter(condition);
}
function simplifyHTML(htmlString) {
    var parser = new DOMParser();
    var doc = parser.parseFromString(htmlString, "text/html");
    var elements = doc.querySelectorAll("*");
    elements.forEach(function (element) {
        var attributes = Array.from(element.attributes);
        attributes.forEach(function (attr) { return element.removeAttribute(attr.name); });
    });
    return doc.body.innerHTML;
}
function simplifyHTMLWithRegex(htmlString) {
    var strippedAttributes = htmlString.replace(/<([\w]+)\s*[^>]*>/g, "<$1>");
    var strippedSelfClosing = strippedAttributes.replace(/<([\w]+)\s*\/>/g, "<$1>");
    return strippedSelfClosing;
}
function replaceAllElements(htmlString, newElement) {
    var replacedOpeningTags = htmlString.replace(/<(\w+)(\s*[^>]*)>/g, "<".concat(newElement, "$2>"));
    var replacedTags = replacedOpeningTags.replace(/<\/\w+>/g, "</".concat(newElement, ">"));
    return replacedTags;
}
function replaceElementName(htmlString, oldElement, newElement) {
    var replacedOpeningTags = htmlString.replace(new RegExp("<".concat(oldElement, "(\\s*\n[^>]*)>"), "gi"), "<".concat(newElement, "$1>"));
    var replacedTags = replacedOpeningTags.replace(new RegExp("</".concat(oldElement, ">"), "gi"), "</".concat(newElement, ">"));
    return replacedTags;
}
function removeChildren(parentElement) {
    while (parentElement.firstChild) {
        parentElement.removeChild(parentElement.firstChild);
    }
}
function addClassToAll(selector, className) {
    var elements = document.querySelectorAll(selector);
    elements.forEach(function (element) { return element.classList.add(className); });
}
function addClassesToAll(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var elements = document.querySelectorAll(selector);
    var _loop_1 = function (index_1) {
        var cls = classNames[index_1];
        elements.forEach(function (element) { return element.classList.add(cls); });
    };
    for (var index_1 = 0; index_1 < classNames.length; index_1++) {
        _loop_1(index_1);
    }
}
function css(selector, propertyName, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.style.setProperty(propertyName, value);
    return el;
}
function attr(selector, attribute, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.setAttribute(attribute, value);
    return el;
}
function removeAttr(selector, attribute) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.removeAttribute(attribute);
    return el;
}
function hasClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return false;
    }
    return el.classList.contains(className);
}
function addClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.add(className);
    return el;
}
function addClasses(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    for (var index_2 = 0; index_2 < classNames.length; index_2++) {
        var cls = classNames[index_2];
        el.classList.add(cls);
    }
    return el;
}
function removeClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.remove(className);
    return el;
}
function removeClasses(selector) {
    var classNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classNames[_i - 1] = arguments[_i];
    }
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    for (var index_3 = 0; index_3 < classNames.length; index_3++) {
        var cls = classNames[index_3];
        el.classList.remove(cls);
    }
    return el;
}
function toggleClass(selector, className) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.classList.toggle(className);
    return el;
}
function offsetOf(el) {
    var rect = el.getBoundingClientRect();
    return {
        left: rect.left + window.scrollX,
        top: rect.top + window.scrollY,
    };
}
function offset(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    var rect = el.getBoundingClientRect();
    return {
        left: rect.left + window.scrollX,
        top: rect.top + window.scrollY,
    };
}
function parent(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.parentElement;
}
function parentNode(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.parentNode;
}
function dataOf(element, key, value) {
    if (typeof value !== "undefined") {
        element.dataset[key] = String(value);
    }
    else {
        return element.dataset[key];
    }
}
function data(selector, key, value) {
    var element = document.querySelector(selector);
    if (!element) {
        return null;
    }
    if (typeof value !== "undefined") {
        element.dataset[key] = String(value);
    }
    else {
        return element.dataset[key];
    }
}
function positionOf(el) {
    return { left: el.offsetLeft, top: el.offsetTop };
}
function position(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return { left: el.offsetLeft, top: el.offsetTop };
}
function scrollTopOf(el, value) {
    if (value !== undefined) {
        el.scrollTop = value;
        return el;
    }
    else {
        return el.scrollTop;
    }
}
function scrollLeftOf(el, value) {
    if (value !== undefined) {
        el.scrollLeft = value;
        return el;
    }
    else {
        return el.scrollLeft;
    }
}
function scrollTop(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.scrollTop = value;
        return el;
    }
    else {
        return el.scrollTop;
    }
}
function scrollLeft(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.scrollLeft = value;
        return el;
    }
    else {
        return el.scrollLeft;
    }
}
function heightOf(el, value) {
    if (value !== undefined) {
        el.style.height = value;
        return el;
    }
    else {
        return el.offsetHeight;
    }
}
function height(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.style.height = value;
        return el;
    }
    else {
        return el.offsetHeight;
    }
}
function removeOf(el) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.removeChild(el);
}
function removeBy(selector) {
    var _a;
    var el = document.querySelector(selector);
    if (el)
        (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.removeChild(el);
}
function emptyOf(el) {
    el.innerHTML = "";
    return el;
}
function empty(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    el.innerHTML = "";
    return el;
}
function cloneOf(el) {
    return el.cloneNode(true);
}
function cloneBy(selector) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    return el.cloneNode(true);
}
function htmlOf(el, value) {
    if (value !== undefined) {
        el.innerHTML = value;
        return el;
    }
    else {
        return el.innerHTML;
    }
}
function textOf(el, value) {
    if (value !== undefined) {
        el.textContent = value;
        return el;
    }
    else {
        return el.textContent;
    }
}
function html(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.innerHTML = value;
        return el;
    }
    else {
        return el.innerHTML;
    }
}
function text(selector, value) {
    var el = document.querySelector(selector);
    if (!el) {
        return null;
    }
    if (value !== undefined) {
        el.textContent = value;
        return el;
    }
    else {
        return el.textContent;
    }
}
function append(el, child) {
    el.appendChild(child);
    return el;
}
function prepend(el, child) {
    el.insertBefore(child, el.firstChild);
    return el;
}
function afterHTMLElement(el, sibling) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(sibling, el.nextSibling);
}
function beforeHTMLElement(el, sibling) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(sibling, el);
}
function replaceWith(el, newEl) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.replaceChild(newEl, el);
}
function appendTo(el, parent) {
    parent.appendChild(el);
    return el;
}
function prependTo(el, parent) {
    parent.insertBefore(el, parent.firstChild);
    return el;
}
function insertAfter(el, refEl) {
    var _a;
    (_a = refEl.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(el, refEl.nextSibling);
}
function insertBefore(el, refEl) {
    var _a;
    (_a = refEl.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(el, refEl);
}
function replaceAll(el, selector) {
    document.querySelectorAll(selector).forEach(function (targetEl) {
        var _a;
        var cloneEl = el.cloneNode(true);
        (_a = targetEl.parentNode) === null || _a === void 0 ? void 0 : _a.replaceChild(cloneEl, targetEl);
    });
}
function findHTMLElement(el, selector) {
    return el.querySelectorAll(selector);
}
function filterHTMLElement(els, filterFn) {
    return els.filter(filterFn);
}
function hasHTMLElement(el, selector) {
    return el.querySelector(selector) !== null;
}
function not(els, filterFn) {
    return els.filter(function (e) { return !filterFn(e); });
}
function is(el, selector) {
    return el.matches(selector);
}
function addHTMLElement(el) {
    var elements = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        elements[_i - 1] = arguments[_i];
    }
    return __spreadArray([el], __read(elements), false);
}
function contents(el) {
    return Array.from(el.childNodes);
}
function closest(el, selector) {
    return el.closest(selector);
}
function parents(el, selector) {
    var parents = [];
    for (var parent_1 = el.parentElement; parent_1; parent_1 = parent_1.parentElement) {
        if (!selector || parent_1.matches(selector)) {
            parents.push(parent_1);
        }
    }
    return parents;
}
function parentOf(el) {
    return el.parentElement;
}
function children(el, selector) {
    return Array.from(el.children).filter(function (child) { return !selector || child.matches(selector); });
}
function siblings(el, selector) {
    var _a;
    return Array.from(((_a = el.parentElement) === null || _a === void 0 ? void 0 : _a.children) || []).filter(function (sibling) { return sibling !== el && (!selector || sibling.matches(selector)); });
}
function prevHTMLElement(el) {
    return el.previousElementSibling;
}
function nextHTMLElement(el) {
    return el.nextElementSibling;
}
function index(el) {
    var _a;
    return Array.from(((_a = el.parentElement) === null || _a === void 0 ? void 0 : _a.children) || []).indexOf(el);
}
function wrapHTMLElement(el, wrapper) {
    var _a;
    (_a = el.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(wrapper, el);
    wrapper.appendChild(el);
}
function wrapAll(els, wrapper) {
    var _a;
    if (els.length === 0)
        return;
    (_a = els[0].parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(wrapper, els[0]);
    els.forEach(function (el) { return wrapper.appendChild(el); });
}
function wrapInner(el, wrapper) {
    Array.from(el.childNodes).forEach(function (child) { return wrapper.appendChild(child); });
    el.appendChild(wrapper);
}
function unwrap(el) {
    var parent = el.parentNode;
    if (!parent)
        return;
    while (el.firstChild)
        parent.insertBefore(el.firstChild, el);
    parent.removeChild(el);
}
function val(el, value) {
    if (value !== undefined) {
        el.value = value;
        return el;
    }
    else {
        return el.value;
    }
}
function on(el, event, handler) {
    el.addEventListener(event, handler);
    return el;
}
function off(el, event, handler) {
    el.removeEventListener(event, handler);
    return el;
}
function contains(container, contained) {
    return container.contains(contained);
}
function one(el, event, handler) {
    var listener = function (ev) {
        el.removeEventListener(event, listener);
        handler(ev);
    };
    el.addEventListener(event, listener);
    return el;
}
function trigger(el, event) {
    var evt = new CustomEvent(event, {
        bubbles: true,
        cancelable: false,
    });
    el.dispatchEvent(evt);
    return el;
}
function show(el) {
    el.style.display = "";
    return el;
}
function hide(el) {
    el.style.display = "none";
    return el;
}
function toggle(el) {
    el.style.display = el.style.display === "none" ? "" : "none";
    return el;
}
function $(selector) {
    return document.querySelector(selector);
}
function $$(selector) {
    return document.querySelectorAll(selector);
}
export { $, $$, addClass, addClassToAll, addClasses, addClassesToAll, addHTMLElement, afterHTMLElement, append, appendTo, attr, beforeHTMLElement, children, cloneBy, cloneOf, closest, contains, contents, css, data, dataOf, empty, emptyOf, filterHTMLElement, findChild, findHTMLElement, findParent, findSiblings, getChildrenRecursively, getNChildrenRecursively, getNParentsRecursively, getParentsRecursively, getSiblings, hasClass, hasHTMLElement, height, heightOf, hide, html, htmlOf, index, insertAfter, insertBefore, is, nextHTMLElement, not, off, offset, offsetOf, on, one, parent, parentNode, parentOf, parents, position, positionOf, prepend, prependTo, prevHTMLElement, removeAttr, removeBy, removeChildren, removeClass, removeClasses, removeOf, replaceAll, replaceAllElements, replaceElementName, replaceWith, scrollLeft, scrollLeftOf, scrollTop, scrollTopOf, show, siblings, simplifyHTML, simplifyHTMLWithRegex, text, textOf, toggle, toggleClass, trigger, unwrap, val, wrapAll, wrapHTMLElement, wrapInner, };
//# sourceMappingURL=dom-utilities.js.map